pub struct RsaPrivateKey<'a> {
pub modulus: UintRef<'a>,
pub public_exponent: UintRef<'a>,
pub private_exponent: UintRef<'a>,
pub prime1: UintRef<'a>,
pub prime2: UintRef<'a>,
pub exponent1: UintRef<'a>,
pub exponent2: UintRef<'a>,
pub coefficient: UintRef<'a>,
pub other_prime_infos: Option<OtherPrimeInfos<'a>>,
}Expand description
PKCS#1 RSA Private Keys as defined in RFC 8017 Appendix 1.2.
ASN.1 structure containing a serialized RSA private key:
RSAPrivateKey ::= SEQUENCE {
version Version,
modulus INTEGER, -- n
publicExponent INTEGER, -- e
privateExponent INTEGER, -- d
prime1 INTEGER, -- p
prime2 INTEGER, -- q
exponent1 INTEGER, -- d mod (p-1)
exponent2 INTEGER, -- d mod (q-1)
coefficient INTEGER, -- (inverse of q) mod p
otherPrimeInfos OtherPrimeInfos OPTIONAL
}Note: the version field is selected automatically based on the absence or
presence of the other_prime_infos field.
Fields
modulus: UintRef<'a>n: RSA modulus.
public_exponent: UintRef<'a>e: RSA public exponent.
private_exponent: UintRef<'a>d: RSA private exponent.
prime1: UintRef<'a>p: first prime factor of n.
prime2: UintRef<'a>q: Second prime factor of n.
exponent1: UintRef<'a>First exponent: d mod (p-1).
exponent2: UintRef<'a>Second exponent: d mod (q-1).
coefficient: UintRef<'a>CRT coefficient: (inverse of q) mod p.
other_prime_infos: Option<OtherPrimeInfos<'a>>Additional primes r_3, …, r_u, in order, if this is a multi-prime
RSA key (i.e. version is multi).
Implementations
Sourceimpl<'a> RsaPrivateKey<'a>
impl<'a> RsaPrivateKey<'a>
Sourcepub fn public_key(&self) -> RsaPublicKey<'a>
pub fn public_key(&self) -> RsaPublicKey<'a>
Get the public key that corresponds to this RsaPrivateKey.
Sourcepub fn version(&self) -> Version
pub fn version(&self) -> Version
Get the Version for this key.
Determined by the presence or absence of the
RsaPrivateKey::other_prime_infos field.